Wrapper to mprotect system call. Not all
implementations will guarantee protection.
mprotect(x, i, prot)mmap object.
location and length of pages to protect.
protection flag set by mmapFlags.
Must be one or more of:
‘PROT_NONE’,
‘PROT_READ’,
‘PROT_WRITE’,
‘PROT_EXEC’.
0 upon success, otherwise -1.
This functionality is very experimental, and likely to be of limited use with R, as the result of a page access that is protected is a SIG that isn't likely to be caught by R. This may be of use for other programs sharing resource with R.
‘mprotect’ man page.